=====
Usage
=====
Follow the `Installation <installation.html>`_ document first.
This document describes how to use OVS-DPDK with puppet as well as configuration settings and values they accept.

To use networking-ovs-dpdk with puppet please refer to installation guide in:
`<networking-ovs-dpdk/doc/source/getstarted/puppet/ubuntu.rst>`

Example manifest files are available in:
`<networking-ovs-dpdk/puppet/ovsdpdk/examples/*.pp>`


ovsdpdk settings
-------------------

Configuration options valid for puppet deployments are described in:

`<networking-ovs-dpdk/puppet/ovsdpdk/manifests/init.pp>`

and

`<networking-ovs-dpdk/puppet/ovsdpdk/manifests/params.pp>`
